@@ -1,5 +1,4 @@
 <?php
-
 // Icinga Web 2 X.509 Module | (c) 2018 Icinga GmbH | GPLv2
 
 namespace Icinga\Module\X509\Clicommands;
@@ -7,9 +6,7 @@ namespace Icinga\Module\X509\Clicommands;
 use Icinga\Application\Logger;
 use Icinga\Module\X509\CertificateUtils;
 use Icinga\Module\X509\Command;
-use Icinga\Module\X509\Common\Database;
 use ipl\Sql\Connection;
-use ipl\Sql\Expression;
 
 class ImportCommand extends Command
 {
@@ -33,22 +30,21 @@ class ImportCommand extends Command
             exit(1);
         }
 
+        $db = $this->getDb();
+
         $bundle = CertificateUtils::parseBundle($file);
 
         $count = 0;
 
-        Database::get()->transaction(function (Connection $db) use ($bundle, &$count) {
+        $db->transaction(function (Connection $db) use ($bundle, &$count) {
             foreach ($bundle as $data) {
                 $cert = openssl_x509_read($data);
 
-                list($id, $_) = CertificateUtils::findOrInsertCert($db, $cert);
+                $id = CertificateUtils::findOrInsertCert($db, $cert);
 
                 $db->update(
                     'x509_certificate',
-                    [
-                        'trusted' => 'y',
-                        'mtime'   => new Expression('UNIX_TIMESTAMP() * 1000')
-                    ],
+                    ['trusted' => 'yes'],
                     ['id = ?' => $id]
                 );
 
