@@ -1,5 +1,4 @@
 <?php
-
 // Icinga Web 2 X.509 Module | (c) 2018 Icinga GmbH | GPLv2
 
 namespace Icinga\Module\X509\Clicommands;
@@ -7,7 +6,6 @@ namespace Icinga\Module\X509\Clicommands;
 use Icinga\Application\Logger;
 use Icinga\Module\X509\CertificateUtils;
 use Icinga\Module\X509\Command;
-use Icinga\Module\X509\Common\Database;
 
 class VerifyCommand extends Command
 {
@@ -20,7 +18,9 @@ class VerifyCommand extends Command
      */
     public function indexAction()
     {
-        $verified = CertificateUtils::verifyCertificates(Database::get());
+        $db = $this->getDb();
+
+        $verified = CertificateUtils::verifyCertificates($db);
 
         Logger::info("Checked %d certificate chain%s.", $verified, $verified !== 1 ? 's' : '');
     }
