@@ -1,5 +1,4 @@
 <?php
-
 // Icinga Web 2 X.509 Module | (c) 2018 Icinga GmbH | GPLv2
 
 namespace Icinga\Module\X509\Controllers;
@@ -7,34 +6,17 @@ namespace Icinga\Module\X509\Controllers;
 use Icinga\Exception\NotFoundError;
 use Icinga\Module\X509\Forms\Config\SniConfigForm;
 use Icinga\Module\X509\SniIniRepository;
-use ipl\Html\HtmlString;
-use ipl\Web\Compat\CompatController;
-use ipl\Web\Url;
-use ipl\Web\Widget\ButtonLink;
+use Icinga\Web\Controller;
+use Icinga\Web\Url;
 
-class SniController extends CompatController
+class SniController extends Controller
 {
     /**
      * List all maps
      */
     public function indexAction()
     {
-        $this->getTabs()->add('jobs', [
-            'title'      => $this->translate('Configure Jobs'),
-            'label'      => $this->translate('Jobs'),
-            'url'        => 'x509/jobs',
-            'baseTarget' => '_main'
-
-        ]);
-        $this->addTitleTab($this->translate('SNI'));
-
-        $this->addControl(
-            (new ButtonLink($this->translate('New SNI Map'), Url::fromPath('x509/sni/new'), 'plus'))
-                ->openInModal()
-        );
-        $this->controls->getAttributes()->add('class', 'default-layout');
-
-        $this->view->controls = $this->controls;
+        $this->view->tabs = $this->Module()->getConfigTabs()->activate('sni');
 
         $repo = new SniIniRepository();
 
@@ -46,13 +28,11 @@ class SniController extends CompatController
      */
     public function newAction()
     {
-        $this->addTitleTab($this->translate('New SNI Map'));
-
         $form = $this->prepareForm()->add();
 
         $form->handleRequest();
 
-        $this->addContent(new HtmlString($form->render()));
+        $this->renderForm($form, $this->translate('New SNI Map'));
     }
 
     /**
