@@ -1,10 +1,9 @@
 <?php
-
 // Icinga Web 2 X.509 Module | (c) 2018 Icinga GmbH | GPLv2
 
 /** @var \Icinga\Application\Modules\Module $this */
 
-$section = $this->menuSection(N_('Certificate Monitoring'), array(
+$section = $this->menuSection(N_('X.509'), array(
     'icon'      => 'check',
     'url'       => 'x509/dashboard',
     'priority'  => 40
@@ -20,14 +19,22 @@ $section->add(N_('Certificate Usage'), array(
     'priority'  => 20
 ));
 
-$section->add(N_('Configuration'), [
-    'url'         => 'x509/jobs',
-    'priority'    => 100,
-    'description' => $this->translate('Configure the scan jobs and SNI map')
-]);
-
 $this->provideConfigTab('backend', array(
     'title' => $this->translate('Configure the database backend'),
     'label' => $this->translate('Backend'),
     'url' => 'config/backend'
 ));
+
+$this->provideConfigTab('jobs', array(
+    'title' => $this->translate('Configure the scan jobs'),
+    'label' => $this->translate('Jobs'),
+    'url' => 'jobs'
+));
+
+$this->provideConfigTab('sni', array(
+    'title' => $this->translate('Configure SNI'),
+    'label' => $this->translate('SNI'),
+    'url' => 'sni'
+));
+
+$this->provideCssFile('icons.css');
