@@ -1,16 +1,17 @@
 <?php
-
 // Icinga Web 2 X.509 Module | (c) 2018 Icinga GmbH | GPLv2
 
 namespace Icinga\Module\X509;
 
-use Icinga\Module\X509\Model\X509Certificate;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\Html;
 use ipl\Html\HtmlString;
+use ipl\Translation\Translation;
 
 class DataTable extends BaseHtmlElement
 {
+    use Translation;
+
     protected $tag = 'table';
 
     /**
@@ -57,6 +58,7 @@ class DataTable extends BaseHtmlElement
 
     protected function createColumns()
     {
+
     }
 
     public function renderHeader()
@@ -80,21 +82,18 @@ class DataTable extends BaseHtmlElement
         return Html::tag('thead', Html::tag('tr', $cells));
     }
 
-    protected function renderRow(X509Certificate $row)
+    protected function renderRow($row)
     {
         $cells = [];
 
         foreach ($this->columns as $key => $column) {
-            if (! is_int($key) && $row->hasProperty($key)) {
-                $data = $row->$key;
+            if (! is_int($key) && array_key_exists($key, $row)) {
+                $data = $row[$key];
             } else {
-                $data = null;
-                if (isset($column['column'])) {
-                    if (is_callable($column['column'])) {
-                        $data = call_user_func(($column['column']), $row);
-                    } elseif (isset($row->{$column['column']})) {
-                        $data = $row->{$column['column']};
-                    }
+                if (isset($column['column']) && array_key_exists($column['column'], $row)) {
+                    $data = $row[$column['column']];
+                } else {
+                    $data = null;
                 }
             }
 
@@ -104,7 +103,7 @@ class DataTable extends BaseHtmlElement
                 $content = $data;
             }
 
-            $cells[] = Html::tag('td', $column['attributes'] ?? null, $content);
+            $cells[] = Html::tag('td', isset($column['attributes']) ? $column['attributes'] : null, $content);
         }
 
         return Html::tag('tr', $cells);
@@ -125,12 +124,11 @@ class DataTable extends BaseHtmlElement
         if (empty($rows)) {
             $colspan = count($this->columns);
 
-            $rows = Html::tag(
-                'tr',
+            $rows = Html::tag('tr',
                 Html::tag(
                     'td',
                     ['colspan' => $colspan],
-                    mt('x509', 'No results found.')
+                    $this->translate('No results found.')
                 )
             );
         }
