@@ -1,5 +1,4 @@
 <?php
-
 // Icinga Web 2 X.509 Module | (c) 2018 Icinga GmbH | GPLv2
 
 namespace Icinga\Module\X509;
@@ -14,20 +13,13 @@ class SortAdapter implements Sortable
 {
     protected $select;
 
-    protected $callback;
-
-    public function __construct(Sql\Select $select, \Closure $callback = null)
+    public function __construct(Sql\Select $select)
     {
         $this->select = $select;
-        $this->callback = $callback;
     }
 
     public function order($field, $direction = null)
     {
-        if ($this->callback !== null) {
-            $field = call_user_func($this->callback, $field) ?: $field;
-        }
-
         if ($direction === null) {
             $this->select->orderBy($field);
         } else {
@@ -44,4 +36,5 @@ class SortAdapter implements Sortable
     {
         return $this->select->getOrderBy();
     }
+
 }
